@@ -638,7 +638,7 @@ def test_get_arrivals_departures_observations_by_vehicle():
                 "2024-12-01",
                 "2024-12-01",
             ],
-            "departure_vehicle_id": [123, 123, 123],
+            "departure_vehicle_id": ["123", "123", "123"],
         }
     )
 
